import * as React from 'react'
import styled from 'styled-components'
import Highlight, { defaultProps } from 'prism-react-renderer'
import PrismTheme from '../../utilities/prism-themes/dark'

const Base = styled('figure')({
  margin: 0,
})

const Title = styled('figcaption')({
  textTransform: 'uppercase',
  fontWeight: 'bolder',
  fontSize: '0.75rem',
})

const CodeBlock = ({ children }) => {
  const { props, } = children
  const { children: code, className, metastring } = props
  const language = typeof className as string === 'string' ? className.split('-')[1] : 'plain'
  const meta = (typeof metastring as string === 'string' && metastring.length > 0)
    ? (metastring as string)
      .split(' ')
      .reduce(
        (m, s) => {
          const [key, value = ''] = s.split('=')
          if (value.trim().length > 0) {
            return {
              ...m,
              [key.trim()]: value.trim(),
            }
          }
          return {
            ...m,
            [key.trim()]: true,
          }
        },
        {}
      )
    : {}
  return (
    <Base>
      {
        meta['title'] && (
          <Title>
            {meta['title']}
          </Title>
        )
      }
      <Highlight
        {...defaultProps}
        language={language}
        code={(code as string).trim()}
        theme={PrismTheme}
      >
        {({ style, tokens, getLineProps, getTokenProps }) => (
          <pre style={style}>
            {tokens.map((line, i) => (
              <div {...getLineProps({ line, key: i })}>
                {line.map((token, key) => (
                  <span {...getTokenProps({ token, key })} />
                ))}
              </div>
            ))}
          </pre>
        )}
      </Highlight>
    </Base>
  )
}

export default CodeBlock
