import * as React from 'react'
import * as PropTypes from 'prop-types'
import Head from 'next/head'
import unified from 'unified'
import parse from 'remark-parse'
import remark2react from 'remark-react'
import docgen from '../../docgen.json'
import pkg from '../../../../../package.json'

const propTypes = {
  of: PropTypes.string,
}

type Props = PropTypes.InferProps<typeof propTypes>

const Header: React.FC<Props> = ({ of: ofAttr }) => {
  const docs = docgen.find(d => d.displayName === ofAttr)

  if (!docs) {
    return null
  }

  return (
    <React.Fragment>
      <Head>
        <title>
          {docs.displayName} | {pkg['title'] || pkg.name}
        </title>
        <meta name="description" content={docs.description} key="description" />
      </Head>
      <h1>{docs.displayName}</h1>
      <p>
        {
          unified()
            .use(parse)
            .use(remark2react)
            .processSync(docs.description).result as any
        }
      </p>
    </React.Fragment>
  )
}

Header.propTypes = propTypes

export default Header
