import * as React from 'react'
import styled from 'styled-components'
import { Icon } from '../../../../react-common/src'

const ToggleWrapper = styled('label')({
  cursor: 'pointer',
  color: 'var(--color-accent)',
  display: 'inline-block',
})

const ToggleInput = styled('input')({
  position: 'absolute',
  left: -999999,
})

const getAutoDetectTheme = () => (
  window.matchMedia('(prefers-color-scheme: dark)').matches
    ? 'Dark'
    : 'Light'
)

const getTheme = () => window.localStorage.getItem('tesseract-theme') || getAutoDetectTheme()

const applyStyles = (theme) => {
  const stylesheets = Array.from(window.document.querySelectorAll('link[title]')) as HTMLLinkElement[]
  stylesheets.forEach(s => {
    const enabled = s.title === theme
    if (enabled) {
      s.setAttribute('rel', 'stylesheet')
      s.removeAttribute('disabled')
    } else {
      s.setAttribute('rel', 'alternate stylesheet')
      s.setAttribute('disabled', 'disabled')
    }
  })
}

const handleInitializeTheme = (initialTheme: string) => () => {
  applyStyles(getTheme() || initialTheme)
}

const ThemeToggle = ({
  initialTheme,
}) => {
  const [theme, setTheme] = React.useState(initialTheme!)

  const handleSetTheme = (t: string) => () => {
    setTheme(t)
  }

  React.useEffect(() => {
    window.localStorage.setItem('tesseract-theme', theme as string)
  }, [theme])

  React.useEffect(() => {
    applyStyles(theme)
  }, [theme])

  React.useEffect(() => {
    const handler = handleInitializeTheme(initialTheme)
    window.addEventListener('load', handler)
    return () => {
      window.removeEventListener('load', handler)
    }
  }, [initialTheme])

  return (
    <ToggleWrapper>
      <ToggleInput
        type="checkbox"
        defaultChecked={theme === 'Dark'}
        onChange={handleSetTheme(theme === 'Dark' ? 'Light' : 'Dark')}
      />
      <span>
        {
          theme === 'Dark'
          && (
            <Icon
              label="Set Light Mode"
              name="moon"
            />
          )
        }
        {
          theme === 'Light'
          && (
            <Icon
              label="Set Dark Mode"
              name="sun"
            />
          )
        }
      </span>
    </ToggleWrapper>
  )
}

export default ThemeToggle
