import * as React from 'react'
import { MDXProvider } from '@mdx-js/react'
import Head from 'next/head'
import styled from 'styled-components'
import sidebar from '../sidebar.json'
import brand from '../../brand'
import Sidebar from '../components/Sidebar/Sidebar'
import pkg from '../../../../package.json'
import CodeBlock from '../components/CodeBlock/CodeBlock'

const Container = styled('div')({
  maxWidth: 720,
  margin: '0 auto',
  padding: '0 1rem',
  boxSizing: 'border-box',
})

const Main = styled('main')({
  margin: '4rem 0',
})

type AppProps = {
  Component: React.ElementType,
  pageProps: Record<string, unknown>,
}

const App: React.FC<AppProps> = ({
  Component,
  pageProps,
}) => (
  <React.Fragment>
    <Head>
      <title>{pkg['title'] || pkg.name}</title>
      <meta name="description" content={pkg.description} key="description" />
    </Head>
    <Sidebar
      brand={brand}
      data={sidebar}
      initialTheme="Dark"
    />
    <Main>
      <Container>
        <MDXProvider
          components={{
            pre: CodeBlock,
          }}
        >
          <Component
            {...pageProps}
          />
        </MDXProvider>
      </Container>
    </Main>
  </React.Fragment>
)

export default App
